Welcome to Brownant
===================

Brownant is a lightweight web data extracting framework.


User's Guide
------------

.. toctree::
   :maxdepth: 2

   userguide/introduction

.. toctree::
   :maxdepth: 2

   userguide/quickstart


API Reference
-------------

.. toctree::
   :maxdepth: 2

   api


Release Changes
---------------

.. toctree::
   :maxdepth: 2

   changes


Author & Contributor
--------------------

.. include:: ../AUTHORS
   :start-line: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

